stac.parametric_tests.anova_within_test — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# stac.parametric_tests.anova_within_test

`stac.parametric_tests.` `anova_within_test`(*args)

  Performs a 1-way ANOVA within cases. Tests the hypothesis that in a set of k dependent sample groups (where k >= 2) at least two of the groups represent populations with different mean values.

  Parameters: | sample1, sample2, ... : array_like The sample measurements for each group.
  Returns: | F-value : float The computed F-value of the test. p-value : float The associated p-value from the F-distribution. pivots : array_like The pivotal quantities for each group.

  References

  D.J. Sheskin, Handbook of parametric and nonparametric statistical procedures. crc Press, 2003, Test 24: The Single-Factor Within-Subjects Analysis of Variance

### Navigation

- index
- STAC Release Candidate documentation »